find_medoids: Finds the medoids from a distance matrix
Description
This function finds the medoids from a distance matrix. The
medoid is the object that minimizes the sum of distances to all other
objects. This function takes advantage of the RcppParallel package to
compute the medoids in parallel.
Usage
find_medoids(D, memberships = NULL)
Value
A named integer vector specifying the indices of the medoids.